<?php

namespace Ebuy\Cart\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Repository\Filter\RequestFilter;
use Ebuy\Cart\Repositories\Eloquent\Filters\CartPublicFilter;
use Ebuy\Cart\Repositories\Eloquent\Presenters\CartListPresenter;
use Ebuy\Cart\Interfaces\CartRepositoryInterface;

class CartPublicController extends BaseController
{

    /**
     * Constructor.
     *
     * @return void
     */
    public function __construct(CartRepositoryInterface $cart)
    {
        parent::__construct();
        $this->modules = $this->modules(config('ebuy.cart.modules'), 'cart', guard_url('cart'));
        $this->repository = $cart;

    }

    /**
     * Show cart's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $data = $this->repository
            ->pushFilter(RequestFilter::class)
            ->pushFilter(CartPublicFilter::class)
            ->setPresenter(CartListPresenter::class)
            ->simplePaginate($pageLimit)
            // ->withQueryString()
            ->toArray();

        extract($data);
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('cart::cart.names'))
            ->view('cart::public.cart.index')
            ->data(compact('data', 'meta', 'modules'))
            ->output();
    }


    /**
     * Show cart.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $data = $this->repository
            ->findBySlug($slug)
            ->toArray();
        $modules = $this->modules;

        return $this->response->setMetaTitle($data['name'] . trans('cart::cart.name'))
            ->view('cart::public.cart.show')
            ->data(compact('data', 'modules'))
            ->output();
    }

}
