<?php

namespace Ebuy\Cart\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Repository\Filter\RequestFilter;
use Ebuy\Cart\Repositories\Eloquent\Filters\LocationPublicFilter;
use Ebuy\Cart\Repositories\Eloquent\Presenters\LocationListPresenter;
use Ebuy\Cart\Interfaces\LocationRepositoryInterface;

class LocationPublicController extends BaseController
{

    /**
     * Constructor.
     *
     * @return void
     */
    public function __construct(LocationRepositoryInterface $location)
    {
        parent::__construct();
        $this->modules = $this->modules(config('ebuy.cart.modules'), 'cart', guard_url('cart'));
        $this->repository = $location;

    }

    /**
     * Show location's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $data = $this->repository
            ->pushFilter(RequestFilter::class)
            ->pushFilter(LocationPublicFilter::class)
            ->setPresenter(LocationListPresenter::class)
            ->simplePaginate($pageLimit)
            // ->withQueryString()
            ->toArray();

        extract($data);
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('cart::location.names'))
            ->view('cart::public.location.index')
            ->data(compact('data', 'meta', 'modules'))
            ->output();
    }


    /**
     * Show location.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $data = $this->repository
            ->findBySlug($slug)
            ->toArray();
        $modules = $this->modules;

        return $this->response->setMetaTitle($data['name'] . trans('cart::location.name'))
            ->view('cart::public.location.show')
            ->data(compact('data', 'modules'))
            ->output();
    }

}
