<?php

namespace Ebuy\Cart\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Repository\Filter\RequestFilter;
use Ebuy\Cart\Repositories\Eloquent\Filters\ShippingPublicFilter;
use Ebuy\Cart\Repositories\Eloquent\Presenters\ShippingListPresenter;
use Ebuy\Cart\Interfaces\ShippingRepositoryInterface;

class ShippingPublicController extends BaseController
{

    /**
     * Constructor.
     *
     * @return void
     */
    public function __construct(ShippingRepositoryInterface $shipping)
    {
        parent::__construct();
        $this->modules = $this->modules(config('ebuy.cart.modules'), 'cart', guard_url('cart'));
        $this->repository = $shipping;

    }

    /**
     * Show shipping's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $data = $this->repository
            ->pushFilter(RequestFilter::class)
            ->pushFilter(ShippingPublicFilter::class)
            ->setPresenter(ShippingListPresenter::class)
            ->simplePaginate($pageLimit)
            // ->withQueryString()
            ->toArray();

        extract($data);
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('cart::shipping.names'))
            ->view('cart::public.shipping.index')
            ->data(compact('data', 'meta', 'modules'))
            ->output();
    }


    /**
     * Show shipping.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $data = $this->repository
            ->findBySlug($slug)
            ->toArray();
        $modules = $this->modules;

        return $this->response->setMetaTitle($data['name'] . trans('cart::shipping.name'))
            ->view('cart::public.shipping.show')
            ->data(compact('data', 'modules'))
            ->output();
    }

}
