<?php

namespace Ebuy\Cart\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Ebuy\Cart\Models\Cart;

class CartPolicy
{

    /**
     * Determine if the given user can view the cart.
     *
     * @param UserPolicyInterface $authUser
     * @param Cart $cart
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Cart $cart)
    {
        if ($authUser->canDo('cart.cart.view') && $authUser->isAdmin()) {
            return true;
        }

        return $cart->user_id == user_id() && $cart->user_type == user_type();
    }

    /**
     * Determine if the given user can create a cart.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('cart.cart.create');
    }

    /**
     * Determine if the given user can update the given cart.
     *
     * @param UserPolicyInterface $authUser
     * @param Cart $cart
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Cart $cart)
    {
        if ($authUser->canDo('cart.cart.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $cart->user_id == user_id() && $cart->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given cart.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Cart $cart)
    {
        return $cart->user_id == user_id() && $cart->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given cart.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Cart $cart)
    {
        if ($authUser->canDo('cart.cart.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given cart.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Cart $cart)
    {
        if ($authUser->canDo('cart.cart.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
