<?php

namespace Ebuy\Cart\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Ebuy\Cart\Models\Shipping;

class ShippingPolicy
{

    /**
     * Determine if the given user can view the shipping.
     *
     * @param UserPolicyInterface $authUser
     * @param Shipping $shipping
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Shipping $shipping)
    {
        if ($authUser->canDo('cart.shipping.view') && $authUser->isAdmin()) {
            return true;
        }

        return $shipping->user_id == user_id() && $shipping->user_type == user_type();
    }

    /**
     * Determine if the given user can create a shipping.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('cart.shipping.create');
    }

    /**
     * Determine if the given user can update the given shipping.
     *
     * @param UserPolicyInterface $authUser
     * @param Shipping $shipping
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Shipping $shipping)
    {
        if ($authUser->canDo('cart.shipping.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $shipping->user_id == user_id() && $shipping->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given shipping.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Shipping $shipping)
    {
        return $shipping->user_id == user_id() && $shipping->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given shipping.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Shipping $shipping)
    {
        if ($authUser->canDo('cart.shipping.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given shipping.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Shipping $shipping)
    {
        if ($authUser->canDo('cart.shipping.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
